@@ -648,5 +648,110 @@ splitcombine <- function(pop, method=1, dfname="population_hierarchy", sep="_",
     return(pop)
   }
 }
+#==============================================================================#
+#' Remove all non-phylogentically informative loci
+#' 
+#' This function will facilitate in removing phylogenetically uninformative loci
+#' from a \code{\link{genind}} object. The user can specify what is meant by
+#' phylogenetically uninformative with a specification of the cutoff percentage.
+#' Any loci under the cutoff will be removed. For convenience's sake, the
+#' default cutoff is set to 2 individuals.
+#' 
+#' @param pop a \code{\link{genind}} object.
+#' 
+#' @param cutoff \code{numeric}. This is a number from 0 to 1 representing the
+#' minimum percentage of differentiating individuals. Defaults is 2 individuals.
+#'
+#' @param quiet \code{logical}. When \code{quiet = TRUE}, messages indicating
+#' the loci removed will be printed to screen. When \code{quiet = FALSE}, 
+#' nothing will be printed to screen.
+#' 
+#' @return A \code{genind} object with user-defined informative loci.
+#'
+#' @note This will have a few side effects that affect certain analyses. First,
+#' the number of multilocus genotypes might be reduced due to the reduced number
+#' of markers. Second, if you plan on using this data for analysis of the index
+#' of association, be sure to use the standardized version (rbarD) that corrects
+#' for the number of observed loci. 
+#'
+#' @examples
+#' # Load the data set H3N2
+#' data(H3N2)
+#' pop(H3N2) <- H3N2$other$x$country
+#' Nepal <- popsub(H3N2, "Nepal")
+#'
+#' # Using the default 2 individuals.
+#' N.inform <- informloci(Nepal)
+#'
+#' # 5 individuals.
+#' N.informfive <- informloci(Nepal, cutoff = 5/nInd(Nepal))
+#'
+#' # 10 individuals. Too many. Gives warning.
+#' N.informten <- informloci(Nepal, cutoff = 10/nInd(Nepal))
+#'
+#' # Decimate (10%)
+#' N.informdecimated <- informloci(Nepal, cutoff = 0.1)
+#' @export
+#==============================================================================#
+
+informloci <- function(pop, cutoff = 2/nInd(pop), quiet = FALSE){
+  if(!is.genind(pop)){
+    stop("This function only works on genind objects.")
+  }
+  MLG <- mlg(pop, quiet = TRUE)
+  if(MLG < 3){
+    if(!isTRUE(quiet)){
+      cat("Not enough multilocus genotypes to be meaningful.\n")
+    }
+    return(pop)
+  }
+  cutoff <- ifelse(cutoff > 0.5, 1 - cutoff, cutoff)
+  min_ind = round(cutoff*nInd(pop))
+  if(!isTRUE(quiet)){
+    cat("cutoff value:", cutoff*100, "percent (",min_ind,"individuals ).\n")
+  }
+  if(pop@type == "PA"){
+    # cutoff applies to too many or too few typed individuals in AFLP cases.
+    locivals <- apply(pop@tab, 2, sum) %in% min_ind:(nInd(pop) - min_ind)
+    if(!isTRUE(quiet)){
+      if(all(locivals == TRUE)){
+        cat("No sites found with fewer than", min_ind, 
+            "different individuals.\n", fill = 80)
+      }
+      else{
+        cat(sum(!locivals), "uninformative", 
+            ifelse(sum(!locivals) > 1, "loci", "locus"), "found:", 
+            pop@loc.names[!locivals],"\n", fill = 80)
+      }
+    }
+    return(pop[, locivals])
+  }
+  else{
+    # as.loci will put the population factor first when creating the data frame.
+    if(is.null(pop@pop)){
+      locivals <- apply(as.loci(pop), 2, test_table, min_ind, nInd(pop))
+    }
+    else{
+      locivals <- apply(as.loci(pop)[-1], 2, test_table, min_ind, nInd(pop))
+    }
+    if(!isTRUE(quiet)){
+      if(all(locivals == TRUE)){
+        cat("No sites found with fewer than", min_ind, 
+            "different individuals.\n", fill = 80)
+      }
+      else if(sum(locivals) < 2){
+        cat("Fewer than 2 loci found informative. Perhaps you should choose a",
+             "lower cutoff value?\nReturning with no changes.\n")
+            return(pop)
+      }
+      else{
+        cat(sum(!locivals), "uninformative", 
+            ifelse(sum(!locivals) > 1, "loci", "locus"), "found:", 
+            pop@loc.names[!locivals],"\n", fill = 80)
+      }
+    }
+    return(pop[, loc = names(pop@loc.names[locivals])])
+  }
+}
 
 
