@@ -705,14 +705,8 @@ final <- function(Iout, result){
     p.val <- ia.pval(index="Ia", samp2, IarD[1])
     p.val[2] <- ia.pval(index="rbarD", samp2, IarD[2])
     if(hist == TRUE){
-      if(require(ggplot2)){
-        poppr.plot(samp, observed=IarD, pop=namelist$population,
-                          file=namelist$File, pval=p.val, N=nrow(pop@tab))
-      }
-      else{      
-        permut.histogram(samp, IarD, p.val[1], pop=namelist$population, 
-                        file=namelist$File)
-      }
+      poppr.plot(samp, observed=IarD, pop=namelist$population,
+                        file=namelist$File, pval=p.val, N=nrow(pop@tab))
     }
     result <- 1:4
     result[c(1,3)] <- IarD
@@ -983,3 +977,16 @@ guesslengths <- function(vec){
     return(1)
   }
 }
+#==============================================================================#
+# Specifically used to find loci with an excessive number of the same genotype.
+#
+# Public functions utilizing this function:
+# # informloci
+#
+# Internal functions utilizing this function:
+# # none
+#==============================================================================#
+test_table <- function(loc, min_ind, n){
+  tab <- table(loc)
+  return(ifelse(any(tab > n - min_ind), FALSE, TRUE))
+}
